# py-12f-common

[![Quality Check Status](https://github.com/tombenke/py-12f-common/workflows/Quality%20Check/badge.svg)](https://github.com/tombenke/py-12f-common)
![Coverage](./coverage.svg)

## About

This repository holds those infrastructure-level modules,
that every application requires that follows the core 12-factor principles.

This version of the library is compatible with Python versions >=3.8.

You can use pip to install the library from the
[Python Package Index](https://pypi.org/project/py-12f-common/):

```bash
   $ pip install py-12f-common
```

For further information read [the documentation](https://tombenke.github.io/py-12f-common/).
